@@ -1,11 +1,13 @@
 from unittest import TestCase
 
 import semantic_release
-from semantic_release.history import (evaluate_version_bump, get_current_version, get_new_version,
-                                      get_previous_version, replace_version_string)
+from semantic_release.history import (evaluate_version_bump, get_current_version,
+                                      get_current_version_by_tag, get_new_version,
+                                      get_previous_version, replace_version_string, set_new_version)
 from semantic_release.history.logs import generate_changelog, markdown_changelog
 
 from . import mock
+from .mocks import mock_version_file
 
 MAJOR = (
     '221',
@@ -59,11 +61,6 @@ class EvaluateVersionBumpTest(TestCase):
         self.assertEqual(evaluate_version_bump('0.0.0', 'minor'), 'minor')
         self.assertEqual(evaluate_version_bump('0.0.0', 'patch'), 'patch')
 
-    def test_should_account_for_commits_earlier_than_last_commit(self):
-        with mock.patch('semantic_release.history.logs.get_commit_log',
-                        lambda *a, **kw: MAJOR_LAST_RELEASE_MINOR_AFTER):
-            self.assertEqual(evaluate_version_bump('1.1.0'), 'minor')
-
     def test_should_not_skip_commits_mentioning_other_commits(self):
         with mock.patch('semantic_release.history.logs.get_commit_log',
                         lambda *a, **kw: MAJOR_MENTIONING_LAST_VERSION):
@@ -145,6 +142,17 @@ def test_current_version_should_return_correct_version():
     assert get_current_version() == semantic_release.__version__
 
 
+@mock.patch('semantic_release.history.get_last_version', return_value='last_version')
+def test_current_version_should_return_git_version(mock_last_version):
+    assert 'last_version' == get_current_version_by_tag()
+
+
+@mock.patch('semantic_release.history.config.get', return_value='tag')
+@mock.patch('semantic_release.history.get_last_version', return_value=None)
+def test_current_version_should_return_default_version(mock_config, mock_last_version):
+    assert '0.0.0' == get_current_version()
+
+
 class GetPreviousVersionTests(TestCase):
 
     @mock.patch('semantic_release.history.get_commit_log',
@@ -187,7 +195,8 @@ class MarkdownChangelogTests(TestCase):
             'breaking': [('21', 'Uses super-feature as default instead of dull-feature.')],
             'feature': [('145', 'Add non-breaking super-feature'), ('134', 'Add super-feature')],
             'fix': [('234', 'Fix bug in super-feature')],
-            'documentation': [('0', 'Document super-feature')]
+            'documentation': [('0', 'Document super-feature')],
+            'performance': [],
         })
         self.assertEqual(
             markdown,
@@ -210,7 +219,14 @@ class MarkdownChangelogTests(TestCase):
         self.assertEqual(
             markdown_changelog(
                 '1.0.1',
-                {'refactor': [], 'breaking': [], 'feature': [], 'fix': [], 'documentation': []},
+                {
+                    'refactor': [],
+                    'breaking': [],
+                    'feature': [],
+                    'fix': [],
+                    'documentation': [],
+                    'performance': [],
+                },
             ),
             ''
         )
@@ -220,7 +236,14 @@ class MarkdownChangelogTests(TestCase):
             '## v1.0.1\n',
             markdown_changelog(
                 '1.0.1',
-                {'refactor': [], 'breaking': [], 'feature': [], 'fix': [], 'documentation': []},
+                {
+                    'refactor': [],
+                    'breaking': [],
+                    'feature': [],
+                    'fix': [],
+                    'documentation': [],
+                    'performance': [],
+                },
                 header=True
             )
         )
@@ -230,6 +253,27 @@ class MarkdownChangelogTests(TestCase):
             'v1.0.1',
             markdown_changelog(
                 '1.0.1',
-                {'refactor': [], 'breaking': [], 'feature': [], 'fix': [], 'documentation': []},
+                {
+                    'refactor': [],
+                    'breaking': [],
+                    'feature': [],
+                    'fix': [],
+                    'documentation': [],
+                    'performance': [],
+                },
             )
         )
+
+
+@mock.patch('builtins.open', mock_version_file)
+@mock.patch('semantic_release.history.config.get', return_value='my_version_path:my_version_var')
+def test_set_version(mock_config):
+
+    set_new_version('X.Y.Z')
+
+    handle_open = mock_version_file()
+    mock_version_file.assert_any_call('my_version_path', mode='w')
+    mock_version_file.assert_any_call('my_version_path', mode='r')
+    handle_open.read.assert_called_once_with()
+    handle_open.write.assert_called_once_with('my_version_var = \'X.Y.Z\'')
+    mock_version_file.reset_mock()
